==> cdk_2.5.orig.tar.gz: cdk-cdk-2.5/display/render/src/test/java/org/openscience/cdk/renderer/color/JmolColorsTest.java <==
/* Copyright (C) 2021  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All we ask is that proper credit is given for our work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.renderer.color;

import java.awt.Color;

import org.junit.Assert;
import org.junit.Test;
import org.openscience.cdk.Atom;
import org.openscience.cdk.CDKTestCase;
import org.openscience.cdk.PseudoAtom;
import org.openscience.cdk.interfaces.IAtom;

/**
 * @cdk.module test-render
 */
public class JmolColorsTest extends CDKTestCase {

    @Test
    public void testGetAtomColor() {
    	IAtomColorer colors = new JmolColors();
        Assert.assertNotNull(colors);
        Assert.assertEquals(
        	new Color(0xFFFFFF).getRGB(), colors.getAtomColor(new Atom("H")).getRGB()
        );
    }

    @Test
    public void testGetDefaultAtomColor() {
    	IAtomColorer colors = new JmolColors();

        Assert.assertNotNull(colors);
        IAtom imaginary = new PseudoAtom("Ix");
        Assert.assertEquals(
           	new Color(0xB31FBA).getRGB(), colors.getAtomColor(imaginary).getRGB()
        );
    }
}

==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/display/render/src/test/java/org/openscience/cdk/renderer/color/JmolColorsTest.java <==
/* Copyright (C) 2021  Egon Willighagen <egonw@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All we ask is that proper credit is given for our work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.renderer.color;

import java.awt.Color;

import org.junit.Assert;
import org.junit.Test;
import org.openscience.cdk.Atom;
import org.openscience.cdk.test.CDKTestCase;
import org.openscience.cdk.PseudoAtom;
import org.openscience.cdk.interfaces.IAtom;

/**
 * @cdk.module test-render
 */
public class JmolColorsTest extends CDKTestCase {

    @Test
    public void testGetAtomColor() {
    	IAtomColorer colors = new JmolColors();
        Assert.assertNotNull(colors);
        Assert.assertEquals(
        	new Color(0xFFFFFF).getRGB(), colors.getAtomColor(new Atom("H")).getRGB()
        );
    }

    @Test
    public void testGetDefaultAtomColor() {
    	IAtomColorer colors = new JmolColors();

        Assert.assertNotNull(colors);
        IAtom imaginary = new PseudoAtom("Ix");
        Assert.assertEquals(
           	new Color(0xB31FBA).getRGB(), colors.getAtomColor(imaginary).getRGB()
        );
    }
}
